/* io.h - I/O operations */
 
/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
 

#ifndef IO_H
#define IO_H

#include <linux/atmsvc.h>


int open_all(int interface);
void poll_loop(void);
void close_all(void);

void to_kernel(struct atmsvc_msg *msg);
void to_net(void *msg,int size);

int get_addr(int itf,struct sockaddr_atmsvc *addr);

#endif
